==> react-web-1.0.63.tgz: package/src/components/UploadFiles/UploadFiles.tsx <==
import React, { useImperativeHandle, useRef, useState } from 'react';
import { useEventListener } from '@devesharp/react-hooks';
import { UploadManager, IFile, IUploadManagerOptions } from '@devesharp/upload-files-js';
import Style from './UploadFiles.style';

interface IPropsUploadFiles extends React.ComponentProps<any> {
   drag?: boolean;
   multiple?: boolean;
   options: IUploadManagerOptions;
}

export interface IRefUploadFiles extends React.ComponentProps<any> {
   cancelFile: (file: IFile) => void;
   retryFilesError: () => void;
}

export const UploadFiles = React.forwardRef<IRefUploadFiles, IPropsUploadFiles>(function UploadFiles(
   { drag = false, multiple = false, options, children }: IPropsUploadFiles,
   ref: any,
) {
   const inputRef = useRef<any>();

   const uploadManager = useRef<UploadManager>(new UploadManager(options)).current;
   const [dragging, setDragging] = useState(false);

   function dropFile(ev: any): void {
      if (drag) {
         ev.preventDefault();
         setDragging(false);
         Array.from(ev.dataTransfer.files).forEach((file) => uploadManager.addFile(file as File));
      }
   }

   function onChangeFile(ev: any): void {
      Array.from(ev.target.files).forEach((file) => uploadManager.addFile(file as File));
      if (inputRef.current) {
         inputRef.current.value = '';
      }
   }

   useEventListener(
      'drop',
      (ev) => {
         if (!drag) {
            ev.preventDefault();
         }
      },
      inputRef,
   );

   useImperativeHandle(
      ref,
      () => ({
         cancelFile: (file: IFile) => {
            uploadManager.cancelFile(file);
         },
         retryFilesError: () => {
            uploadManager.retryFilesError();
         },
      }),
      [],
   );

   return (
      <Style
         onDragEnter={() => drag && setDragging(true)}
         onDragLeave={() => drag && setDragging(false)}
         onDrop={dropFile}
      >
         <input type="file" ref={inputRef} onChange={onChangeFile} multiple={multiple} />
         {children({ dragging })}
      </Style>
   );
});

==> react-web-2.0.48.tgz: package/src/components/UploadFiles/UploadFiles.tsx <==
import React, { useImperativeHandle, useRef, useState } from 'react';
import { useEventListener } from '@devesharp/react-hooks';
import { UploadManager, IFile, IUploadManagerOptions } from '@devesharp/upload-files-js';
import Style from './UploadFiles.style';

interface IPropsUploadFiles {
   drag?: boolean;
   multiple?: boolean;
   options: IUploadManagerOptions;
   children: any;
}

export interface IRefUploadFiles {
   cancelFile: (file: IFile) => void;
   retryFilesError: () => void;
}

export const UploadFiles = React.forwardRef<IRefUploadFiles, IPropsUploadFiles>(function UploadFiles(
   { drag = false, multiple = false, options, children }: IPropsUploadFiles,
   ref: any,
) {
   const inputRef = useRef<any>();

   const uploadManager = useRef<UploadManager>(new UploadManager(options)).current;
   const [dragging, setDragging] = useState(false);

   function dropFile(ev: any): void {
      if (drag) {
         ev.preventDefault();
         setDragging(false);
         Array.from(ev.dataTransfer.files).forEach((file) => uploadManager.addFile(file as File));
      }
   }

   function onChangeFile(ev: any): void {
      Array.from(ev.target.files).forEach((file) => uploadManager.addFile(file as File));
      if (inputRef.current) {
         inputRef.current.value = '';
      }
   }

   useEventListener(
      'drop',
      (ev) => {
         if (!drag) {
            ev.preventDefault();
         }
      },
      inputRef,
   );

   useImperativeHandle(
      ref,
      () => ({
         cancelFile: (file: IFile) => {
            uploadManager.cancelFile(file);
         },
         retryFilesError: () => {
            uploadManager.retryFilesError();
         },
      }),
      [],
   );

   return (
      <Style
         onDragEnter={() => drag && setDragging(true)}
         onDragLeave={() => drag && setDragging(false)}
         onDrop={dropFile}
      >
         <input type="file" ref={inputRef} onChange={onChangeFile} multiple={multiple} />
         {children({ dragging })}
      </Style>
   );
});
